/*
 * @Company: 沈阳信诚科技
 * @Email: html_venustar@163.com
 * @Author: Liuqiming
 * @Description: 
 * @LastEditors: Liuqiming
 * @LastEditTime: 2024-03-15 15:16:25
 * @Date: 2024-03-14 10:12:55
 */
import request from '@/utils/request'

// 班组,班组长
export function queryTeamInfo(time) {
  return request({
    url: '/system/team/queryTeamInfo?time=' + time,
    method: 'get',
  })
}

// 质量对比
export function qualityMonthCompare() {
  return request({
    url: '/quality/qualityMonthCompare',
    method: 'post',
  })
}
// 本年度各班组质量情况
export function qualitySituationOfTeam() {
  return request({
    url: '/quality/qualitySituationOfTeam',
    method: 'post',
  })
}
// 成本费用
export function costingPie(month) {
  return request({
    url: '/business/costingInformation/costingPie?monthNum=' + month,
    method: 'get',
  })
}
// 月度产量统计
export function currentYearMonthlyProductionStatistics() {
  return request({
    url: '/busses/l2L3RepProdData/currentYearMonthlyProductionStatistics',
    method: 'get',
  })
}
// 机组生产监控
export function realTimeData() {
  return request({
    url: '/unitMonitoring/realTimeData',
    method: 'post',
  })
}
// 班组产量对比
export function everyTeamProductionStatistics() {
  return request({
    url: '/busses/l2L3RepProdData/everyTeamProductionStatistics',
    method: 'get',
  })
}
// 班组成本对比
export function teamCostComparison(month) {
  return request({
    url: '/teamStatistics/teamCostComparison?monthNum=' + month,
    method: 'get',
  })
}